Termbox::PP
Termbox::PP is a minimalistic terminal UI library in pure Perl
Description
Termbox::PP provides a small and consistent API for building text-based user interfaces in Perl.
It focuses on the common subset of functionality shared across modern terminal emulators, offering a simple and portable abstraction.
Features
Portable abstraction
Provides a minimal set of functions that work consistently across different terminal environments.
Small and simple API
The limited API surface makes the module easy to learn, test, and maintain.
Pure Perl implementation
The module is implemented entirely in Perl and does not require XS or any external C libraries. It only depends on core modules available since Perl v5.10.
Warning
This port of termbox2 is still quite new and still has to prove itself in production use and possibly be improved.
Install
To install the Termbox::PP module type the following:
cpan Termbox::PP
Manual install:
perl Makefile.PL
make
make install
Examples
For examples of what you can do, see the various examples in the example/ directory. You can try them out via:
perl example/hello_world.pl
Credits
Termbox::PP is a port of termbox2.
Author
2024-2026 J. Schneider <http://github.com/brickpool>
Copyright and Licence
Copyright (c) 2010-2026 by termbox developers
MIT License